pub struct ChannelOffloadExtStartOffloadResponse {
pub offload_parameters: Option<L2capChannelOffloadParameters>,
/* private fields */
}Fields
offload_parameters: Option<L2capChannelOffloadParameters>Trait Implementations
Sourceimpl Clone for ChannelOffloadExtStartOffloadResponse
impl Clone for ChannelOffloadExtStartOffloadResponse
Sourcefn clone(&self) -> ChannelOffloadExtStartOffloadResponse
fn clone(&self) -> ChannelOffloadExtStartOffloadResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<ChannelOffloadExtStartOffloadResponse, D> for ChannelOffloadExtStartOffloadResponse
impl<D: ResourceDialect> Decode<ChannelOffloadExtStartOffloadResponse, D> for ChannelOffloadExtStartOffloadResponse
Sourceimpl Default for ChannelOffloadExtStartOffloadResponse
impl Default for ChannelOffloadExtStartOffloadResponse
Sourcefn default() -> ChannelOffloadExtStartOffloadResponse
fn default() -> ChannelOffloadExtStartOffloadResponse
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<ChannelOffloadExtStartOffloadResponse, D> for &ChannelOffloadExtStartOffloadResponse
impl<D: ResourceDialect> Encode<ChannelOffloadExtStartOffloadResponse, D> for &ChannelOffloadExtStartOffloadResponse
Sourceimpl PartialEq for ChannelOffloadExtStartOffloadResponse
impl PartialEq for ChannelOffloadExtStartOffloadResponse
Sourcefn eq(&self, other: &ChannelOffloadExtStartOffloadResponse) -> bool
fn eq(&self, other: &ChannelOffloadExtStartOffloadResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for ChannelOffloadExtStartOffloadResponse
impl TypeMarker for ChannelOffloadExtStartOffloadResponse
Sourcetype Owned = ChannelOffloadExtStartOffloadResponse
type Owned = ChannelOffloadExtStartOffloadResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ChannelOffloadExtStartOffloadResponse
impl ValueTypeMarker for ChannelOffloadExtStartOffloadResponse
Sourcetype Borrowed<'a> = &'a ChannelOffloadExtStartOffloadResponse
type Borrowed<'a> = &'a ChannelOffloadExtStartOffloadResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for ChannelOffloadExtStartOffloadResponse
impl StructuralPartialEq for ChannelOffloadExtStartOffloadResponse